#-----------------------------------------------------------------------------
%{?!dist:	%define	dist	.ok}
#-----------------------------------------------------------------------------
Name		:	rsync
Version		:	3.2.7
Release		:	17.2.0.rel%{?dist}
Summary		:	Summary: A fast, versatile, remote (and local) file-copying tool
Group		:	Applications/Internet

Packager	:	Osukiss Project	<build-ok@osukiss.org>

License		:	GPL
URL		:	https://www.samba.org/ftp/rsync/src

Source0		:	%{name}-%{version}.tar.gz

#-----------------------------------------------------------------------------
BuildRequires	:	autoconf
BuildRequires	:	gcc
BuildRequires	:	gcc-c++
BuildRequires	:	openssl-devel
BuildRequires	:	popt
BuildRequires	:	xxHash-devel
BuildRequires	:	lz4-devel
BuildRequires	:	zstd-devel

Requires	:	openssh-clients
Requires	:	shadow
#-----------------------------------------------------------------------------
%description
Rsync is a fast and extraordinarily versatile file copying tool.  It can
copy locally, to/from another host over any remote shell, or to/from a
remote rsync daemon.  It offers a large number of options that control
every aspect of its behavior and permit very flexible specification of the
set of files to be copied.  It is famous for its delta-transfer algorithm,
which reduces the amount of data sent over the network by sending only the
differences between the source files and the existing files in the
destination.  Rsync is widely used for backups and mirroring and as an
improved copy command for everyday use.

#-----------------------------------------------------------------------------
%files			
%defattr(-,root,root,-)
%doc COPYING support/ tech_report.tex
%{_sysconfdir}/xinetd.d/rsync
%{_bindir}/%{name}
%{_bindir}/%{name}-ssl
%{_mandir}/man1/rsync.1.gz
%{_mandir}/man1/rsync-ssl.1.gz
%{_mandir}/man5/rsyncd.conf.5.gz

#=============================================================================
%package		ssl-daemon
Summary		:	Service for anonymous access to rsync

#-----------------------------------------------------------------------------
BuildArch	:	noarch

Requires	:	%{name} = %{version}-%{release}
#-----------------------------------------------------------------------------
%description		 ssl-daemon
Provides a config file for stunnel that will (if you start
your stunnel service) cause stunnel to listen for ssl rsync-daemon
connections and run "rsync --daemon" to handle them.

#-----------------------------------------------------------------------------
%files			ssl-daemon
%defattr(-,root,root,-)
%config(noreplace) %{_sysconfdir}/stunnel/rsyncd.conf

#-----------------------------------------------------------------------------
%pre			ssl-daemon
if [ "$1" = 1 ]; then
  /usr/sbin/groupadd				\
	-K GID_MIN=50				\
	-K GID_MAX=99				\
	 %{name}d

  /usr/sbin/useradd 				\
	-r					\
	-c "Rsync daemon"			\
	-K SYS_UID_MIN=50			\
	-K SYS_UID_MAX=99			\
	-g %{name}d				\
	-s /sbin/nologin			\
	-d %{_var}/privsep/%{name}		\
	%{name}d
  fi

#-----------------------------------------------------------------------------
#after upgrade or remove
%preun		ssl-daemon
if [ "$1" = 0 ]; then
  %{_sysconfdir}/rc.d/init.d/%{daemon} stop > /dev/null 2>&1 || :
  /usr/sbin/userdel %{name}d
  /usr/sbin/groupdel %{name}d
  (
  /bin/echo -n "%{name}-ssl-daemon-%{version} has been fully removed on "; 
  date;
  ) > %{_var}/log/README-%{name}-removed
  fi
#=============================================================================
%prep
%setup -q

# Avoid extra perl dependencies for scripts going into doc dir.
chmod -x support/*

#-----------------------------------------------------------------------------
#building application
%build

autoreconf -vif
./configure						\
        --prefix=%{_prefix}				\
        --includedir=%{_includedir}/ssh			\
	--exec-prefix=%{_exec_prefix}			\
	--libexecdir=%{_libexecdir}/%{name}		\
        --sysconfdir=%{_sysconfdir}/ssh			\
        --sbindir=%{_sbindir}				\
	--mandir=%{_mandir}				\
	--libdir=%{_libdir}				\
	--infodir=%{_infodir}				\
	--docdir=%{_defaultdocdir}/%{name}-%{version}	\
	--without-included-zlib				\
	--enable-lz4					\
	--enable-xxhash					\

%{__make} reconfigure

%define _smp_mflags -j%(/usr/bin/getconf _NPROCESSORS_ONLN)
%{__make} %{_smp_mflags}

#-----------------------------------------------------------------------------
%clean
%{__rm} -rf %{buildroot}

#-----------------------------------------------------------------------------
#installing program
%install
%{__rm} -rf %{buildroot}

%{__make}						\
	DESTDIR=%{buildroot}				\
	INSTALLCMD='install -p'				\
	INSTALLMAN='install -p'				\
	install						\
	install-ssl-daemon				\


%{__mkdir_p}						\
	%{buildroot}%{_sysconfdir}/xinetd.d		\
	%{buildroot}%{_sysconfdir}/rsync-ssl/certs

install -m 644						\
	packaging/lsb/rsync.xinetd			\
	%{buildroot}%{_sysconfdir}/xinetd.d/rsync


#-----------------------------------------------------------------------------
%changelog
